@@ -19,8 +19,10 @@ makedocs(;
     pages = [
         "Home" => "index.md",
         "Overview" => "intro.md",
+        "Philosophy" => "philosophy.md",
         "Manual" => [
             "Constructing intervals" => "manual/construction.md",
+            "Guarantee and `ExactReal`" => "manual/guarantee.md",
             "Usage" => "manual/usage.md",
             "Configuration" => "manual/configuration.md",
             "Symbols" => "manual/symbols.md",
