@@ -13,10 +13,12 @@ end
 
 # contructor for `UniformScaling`
 
-IntervalArithmetic.interval(::Type{T}, J::LinearAlgebra.UniformScaling, d::IntervalArithmetic.Decoration = com; format::Symbol = :infsup) where {T} =
-    LinearAlgebra.UniformScaling(interval(T, J.λ, d; format = format))
-IntervalArithmetic.interval(J::LinearAlgebra.UniformScaling, d::IntervalArithmetic.Decoration = com; format::Symbol = :infsup) =
-    LinearAlgebra.UniformScaling(interval(J.λ, d; format = format))
+IntervalArithmetic._interval_infsup(::Type{T}, J::LinearAlgebra.UniformScaling, H::LinearAlgebra.UniformScaling, d::IntervalArithmetic.Decoration) where {T<:IntervalArithmetic.NumTypes} =
+    LinearAlgebra.UniformScaling(IntervalArithmetic._interval_infsup(T, J.λ, H.λ, d))
+
+IntervalArithmetic._infer_numtype(J::LinearAlgebra.UniformScaling) = numtype(eltype(J))
+
+IntervalArithmetic.exact(J::LinearAlgebra.UniformScaling) = LinearAlgebra.UniformScaling(exact(J.λ))
 
 # by-pass generic `opnorm` from LinearAlgebra to prevent NG flag
 
@@ -119,6 +121,43 @@ end
 LinearAlgebra.det(A::AbstractMatrix{<:Interval}) = real(reduce(*, LinearAlgebra.eigvals(A)))
 LinearAlgebra.det(A::AbstractMatrix{<:Complex{<:Interval}}) = reduce(*, LinearAlgebra.eigvals(A))
 
+# matrix eigendecomposition
+# note: use the contraction mapping theorem, only works when the entries of A have small radii, and A has simple eigenvalues
+
+function LinearAlgebra.eigen!(A::AbstractMatrix{<:RealOrComplexI}; permute::Bool=true, scale::Bool=true, sortby::Union{Function,Nothing}=LinearAlgebra.eigsortby)
+    # note: this function does not overwrite `A`
+    true_vls = _eigvals(A, permute, scale, sortby)
+    vcs = LinearAlgebra.eigvecs(mid.(A); permute, scale, sortby)
+    n = length(true_vls)
+    inds = [argmax(i -> abs(vcs[i,j]), 1:n) for j ∈ 1:n]
+    ref_scale = [vcs[inds[j],j] for j ∈ 1:n]
+    foreach(j -> vcs[:,j] ./= ref_scale[j], 1:n)
+    vcs_ = interval(vcs)
+
+    F = [[vcs_[inds[j],j] - interval(1) for j ∈ 1:n] ; vec(A * vcs_ - vcs_ * LinearAlgebra.Diagonal(true_vls))]
+    DF = zeros(eltype(F), n+n^2, n+n^2)
+    for j ∈ 1:n
+        DF[j,n+inds[j]+(j-1)*n] = interval(1)
+        DF[n+(j-1)*n+1:n+j*n,j] .= .- vcs_[:,j]
+        DF[n+(j-1)*n+1:n+j*n,n+(j-1)*n+1:n+j*n] .= A - LinearAlgebra.UniformScaling(true_vls[j])
+    end
+
+    approx_DF⁻¹ = interval(inv(mid.(DF)))
+    Y = LinearAlgebra.norm(approx_DF⁻¹ * F, Inf)
+    Z₁ = LinearAlgebra.opnorm(approx_DF⁻¹ * DF - interval(LinearAlgebra.I), Inf)
+
+    true_vcs = Matrix{eltype(vcs_)}(undef, size(vcs))
+    if isbounded(Y) & strictprecedes(Z₁, one(Z₁))
+        r = sup(Y / (one(Z₁) - Z₁))
+        true_vcs .= interval.(vcs, r; format = :midpoint)
+        foreach(j -> true_vcs[:,j] .*= interval(ref_scale[j]), 1:n)
+    else
+        true_vcs .= nai(eltype(vcs))
+    end
+    _ensure_ng_flag!(true_vcs, all(isguaranteed, A))
+    return LinearAlgebra.Eigen(true_vls, true_vcs)
+end
+
 # matrix inversion
 # note: use the contraction mapping theorem, only works when the entries of A have small radii
 
@@ -126,45 +165,61 @@ function Base.inv(A::Matrix{<:RealOrComplexI})
     mid_A = mid.(A)
     approx_A⁻¹ = interval(inv(mid_A))
     F = A * approx_A⁻¹ - interval(LinearAlgebra.I)
-    Y = LinearAlgebra.opnorm(approx_A⁻¹ * F, Inf)
+    Y = LinearAlgebra.norm(approx_A⁻¹ * F, Inf)
     Z₁ = LinearAlgebra.opnorm(F, Inf)
+    A⁻¹ = Matrix{eltype(A)}(undef, size(A))
     if isbounded(Y) & strictprecedes(Z₁, one(Z₁))
-        A⁻¹ = interval.(approx_A⁻¹, inf(interval(mag(Y)) / (one(Z₁) - interval(mag(Z₁)))); format = :midpoint)
+        r = sup(Y / (one(Z₁) - Z₁))
+        A⁻¹ .= interval.(approx_A⁻¹, r; format = :midpoint)
     else
-        A⁻¹ = fill(nai(eltype(approx_A⁻¹)), size(A))
+        A⁻¹ .= nai(eltype(approx_A⁻¹))
     end
     _ensure_ng_flag!(A⁻¹, all(isguaranteed, A))
     return A⁻¹
 end
 
-# matrix multiplication
+# matrix exponential and logarithm
 
-function IntervalArithmetic.configure_matmul(matmul::Symbol)
-    matmul ∈ (:slow, :fast) || return throw(ArgumentError("only the matrix multiplication mode `:slow` and `:fast` are available"))
-
-    @eval begin
-        function LinearAlgebra.mul!(C::AbstractVector{<:RealOrComplexI}, A::AbstractVecOrMat, B::AbstractVector, α::Number, β::Number)
-            size(A, 2) == size(B, 1) || return throw(DimensionMismatch("The number of columns of A must match the number of rows of B."))
-            return IntervalArithmetic._mul!(IntervalArithmetic.MatMulMode{$(QuoteNode(matmul))}(), C, A, B, α, β)
-        end
-
-        function LinearAlgebra.mul!(C::AbstractMatrix{<:RealOrComplexI}, A::AbstractVecOrMat, B::AbstractVecOrMat, α::Number, β::Number)
-            size(A, 2) == size(B, 1) || return throw(DimensionMismatch("The number of columns of A must match the number of rows of B."))
-            return IntervalArithmetic._mul!(IntervalArithmetic.MatMulMode{$(QuoteNode(matmul))}(), C, A, B, α, β)
-        end
-    end
-
-    return matmul
+function LinearAlgebra.exp!(A::AbstractMatrix{<:RealOrComplexI})
+    # note: this function does not overwrite `A`
+    Λ, V = LinearAlgebra.eigen(A)
+    V⁻¹ = inv(V)
+    return V * LinearAlgebra.Diagonal(exp.(Λ)) * V⁻¹
 end
 
-IntervalArithmetic.configure_matmul(:fast)
+function LinearAlgebra.log(A::AbstractMatrix{<:Interval})
+    Λ, V = LinearAlgebra.eigen(A)
+    any(x -> in_interval(0, x), Λ) && return fill(nai(eltype(A)), size(A))
+    V⁻¹ = inv(V)
+    any(x -> isreal(x) & precedes(real(x), interval(0)), Λ) && return V * LinearAlgebra.Diagonal(log.(complex.(Λ))) * V⁻¹
+    return real(V * LinearAlgebra.Diagonal(log.(Λ)) * V⁻¹)
+end
+
+function LinearAlgebra.log(A::AbstractMatrix{<:ComplexI})
+    Λ, V = LinearAlgebra.eigen(A)
+    any(x -> in_interval(0, x), Λ) && return fill(nai(eltype(A)), size(A))
+    V⁻¹ = inv(V)
+    return V * LinearAlgebra.Diagonal(log.(Λ)) * V⁻¹
+end
+
+# matrix multiplication
+
+function LinearAlgebra.mul!(C::AbstractVector{<:RealOrComplexI}, A::AbstractVecOrMat, B::AbstractVector, α::Number, β::Number)
+    size(A, 2) == size(B, 1) || return throw(DimensionMismatch("The number of columns of A must match the number of rows of B."))
+    return _mul!(IntervalArithmetic.default_matmul(), C, A, B, α, β)
+end
+
+function LinearAlgebra.mul!(C::AbstractMatrix{<:RealOrComplexI}, A::AbstractVecOrMat, B::AbstractVecOrMat, α::Number, β::Number)
+    size(A, 2) == size(B, 1) || return throw(DimensionMismatch("The number of columns of A must match the number of rows of B."))
+    return _mul!(IntervalArithmetic.default_matmul(), C, A, B, α, β)
+end
 
 #
 
 LinearAlgebra.mul!(C::AbstractVecOrMat{<:RealOrComplexI}, A::AbstractMatrix{<:RealOrComplexI}, B::AbstractVecOrMat{<:RealOrComplexI}) =
     LinearAlgebra.mul!(C, A, B, interval(true), interval(false))
 
-function IntervalArithmetic._mul!(::IntervalArithmetic.MatMulMode{:slow}, C, A::AbstractMatrix, B::AbstractVecOrMat, α, β)
+function _mul!(::IntervalArithmetic.MatMulMode{:slow}, C, A::AbstractMatrix, B::AbstractVecOrMat, α, β)
     if iszero(α)
         if iszero(β)
             C .= zero(eltype(C))
@@ -221,14 +276,14 @@ end
 # fast matrix multiplication
 # Note: Rump's algorithm
 
-function IntervalArithmetic._mul!(::IntervalArithmetic.MatMulMode{:fast}, C, A, B, α, β)
+function _mul!(::IntervalArithmetic.MatMulMode{:fast}, C, A, B, α, β)
     if Int == Int32
         @info "Fast multiplication is not supported on 32-bit systems, using the slow version"
-        return IntervalArithmetic._mul!(IntervalArithmetic.MatMulMode{:slow}(), C, A, B, α, β)
+        return _mul!(IntervalArithmetic.MatMulMode{:slow}(), C, A, B, α, β)
     else
         numtype(eltype(C)) <: Union{Float16,Float32,Float64} && return _fastmul!(C, A, B, α, β)
         @info "Fast multiplication is only supported for `Union{Float16,Float32,Float64}`, using the slow version"
-        return IntervalArithmetic._mul!(IntervalArithmetic.MatMulMode{:slow}(), C, A, B, α, β)
+        return _mul!(IntervalArithmetic.MatMulMode{:slow}(), C, A, B, α, β)
     end
 end
 
@@ -413,11 +468,11 @@ function ___mul(A::AbstractMatrix{T}, B::AbstractVecOrMat{Interval{T}}) where {T
 
     stride_A  = _to_stride_64(A)
     stride_mB = _to_stride_64(mB)
-    C₁ = IntervalArithmetic._sub_round.(
+    C₁ = IntervalArithmetic._fround.(-,
         T.(_call_gem_openblas!(cache_2, stride_A, stride_mB, RoundDown), RoundDown),
         T.(rC, RoundUp),
         RoundDown)
-    C₂ = cache_2; C₂ .= IntervalArithmetic._add_round.(
+    C₂ = cache_2; C₂ .= IntervalArithmetic._fround.(+,
         T.(_call_gem_openblas!(cache_2, stride_A, stride_mB, RoundUp), RoundUp),
         T.(rC, RoundUp),
         RoundUp)
@@ -435,11 +490,11 @@ function ___mul(A::AbstractMatrix{Interval{T}}, B::AbstractVecOrMat{T}) where {T
 
     stride_mA = _to_stride_64(mA)
     stride_B  = _to_stride_64(B)
-    C₁ = IntervalArithmetic._sub_round.(
+    C₁ = IntervalArithmetic._fround.(-,
         T.(_call_gem_openblas!(cache_2, stride_mA, stride_B, RoundDown), RoundDown),
         T.(rC, RoundUp),
         RoundDown)
-    C₂ = cache_2; C₂ .= IntervalArithmetic._add_round.(
+    C₂ = cache_2; C₂ .= IntervalArithmetic._fround.(+,
         T.(_call_gem_openblas!(cache_2, stride_mA, stride_B, RoundUp), RoundUp),
         T.(rC, RoundUp),
         RoundUp)
@@ -455,76 +510,33 @@ function ___mul(A::AbstractMatrix{Interval{T}}, B::AbstractVecOrMat{Interval{T}}
     cache_2 = zeros(Float64, size(A, 1), size(B, 2))
 
     absmA_rB = _call_gem_openblas!(cache_1, _to_stride_64(abs.(mA)), _to_stride_64(rB), RoundUp)
-    U = rB; U .= IntervalArithmetic._add_round.(abs.(mB), rB, RoundUp)
+    U = rB; U .= IntervalArithmetic._fround.(+, abs.(mB), rB, RoundUp)
     rA_U = _call_gem_openblas!(cache_2, _to_stride_64(rA), _to_stride_64(U), RoundUp)
 
     cache_3 = zeros(Float64, size(A, 1), size(B, 2))
 
     stride_mA = _to_stride_64(mA)
     stride_mB = _to_stride_64(mB)
-    C₁ = IntervalArithmetic._sub_round.(
+    C₁ = IntervalArithmetic._fround.(-,
         T.(_call_gem_openblas!(cache_3, stride_mA, stride_mB, RoundDown), RoundDown),
-        IntervalArithmetic._add_round.(T.(absmA_rB, RoundUp), T.(rA_U, RoundUp), RoundUp),
+        IntervalArithmetic._fround.(+, T.(absmA_rB, RoundUp), T.(rA_U, RoundUp), RoundUp),
         RoundDown)
-    C₂ = cache_3; C₂ .= IntervalArithmetic._add_round.(
+    C₂ = cache_3; C₂ .= IntervalArithmetic._fround.(+,
         T.(_call_gem_openblas!(cache_3, stride_mA, stride_mB, RoundUp), RoundUp),
-        IntervalArithmetic._add_round.(T.(absmA_rB, RoundUp), T.(rA_U, RoundUp), RoundUp),
+        IntervalArithmetic._fround.(+, T.(absmA_rB, RoundUp), T.(rA_U, RoundUp), RoundUp),
         RoundUp)
 
     return C₁, C₂
 end
 
-# function ___mul(A::AbstractMatrix{Interval{T}}, B::AbstractVecOrMat{Interval{T}}) where {T<:AbstractFloat}
-#     k = size(A, 2)
-#     u2 = eps(T) # twice the unit roundoff
-#     @assert (2k + 2) * u2 ≤ 1
-
-#     mA, rA = _vec_or_mat_midradius(A)
-#     mB, rB = _vec_or_mat_midradius(B)
-
-#     cache_1 = zeros(T, size(A, 1), size(B, 2))
-#     cache_2 = zeros(T, size(A, 1), size(B, 2))
-#     mC, μ = _fused_matmul!(cache_1, cache_2, mA, rA, mB, rB)
-
-#     γ = IntervalArithmetic._add_round.(IntervalArithmetic._mul_round.(convert(T, k + 1), eps.(μ), RoundUp), IntervalArithmetic._mul_round(IntervalArithmetic._inv_round(u2, RoundUp), floatmin(T), RoundUp), RoundUp)
-
-#     U = mA; U .= IntervalArithmetic._add_round.(abs.(mA), rA, RoundUp)
-#     V = mB; V .= IntervalArithmetic._add_round.(abs.(mB), rB, RoundUp)
-
-#     cache_3 = zeros(Float64, size(A, 1), size(B, 2))
-#     rC = IntervalArithmetic._add_round.(IntervalArithmetic._sub_round.(T.(_call_gem_openblas!(cache_3, _to_stride_64(U), _to_stride_64(V), RoundUp), RoundUp), μ, RoundUp), 2 .* γ, RoundUp)
-
-#     C₁ = μ; C₁ .= IntervalArithmetic._sub_round.(mC, rC, RoundDown)
-#     C₂ = γ; C₂ .= IntervalArithmetic._add_round.(mC, rC, RoundUp)
-
-#     return C₁, C₂
-# end
-
-# function _fused_matmul!(mC, μ, mA, rA, mB, rB)
-#     Threads.@threads for j ∈ axes(mB, 2)
-#         for l ∈ axes(mA, 2)
-#             @inbounds for i ∈ axes(mA, 1)
-#                 a, c = mA[i,l], rA[i,l]
-#                 b, d = mB[l,j], rB[l,j]
-#                 e = sign(a) * min(abs(a), c)
-#                 f = sign(b) * min(abs(b), d)
-#                 p = a*b + e*f
-#                 mC[i,j] += p
-#                 μ[i,j] += abs(p)
-#             end
-#         end
-#     end
-#     return mC, μ
-# end
-
 _to_stride_64(A::StridedArray{Float64}) = A
 _to_stride_64(A::StridedArray{<:AbstractFloat}) = Float64.(A, RoundUp)
 _to_stride_64(A::AbstractVector) = _to_stride_64(Vector(A))
 _to_stride_64(A::AbstractMatrix) = _to_stride_64(Matrix(A))
 
 function _vec_or_mat_midradius(A::AbstractVecOrMat{Interval{T}}) where {T<:AbstractFloat}
-    mA = IntervalArithmetic._div_round.(IntervalArithmetic._add_round.(inf.(A), sup.(A), RoundUp), convert(T, 2), RoundUp)
-    rA = IntervalArithmetic._sub_round.(mA, inf.(A), RoundUp)
+    mA = IntervalArithmetic._fround.(/, IntervalArithmetic._fround.(+, inf.(A), sup.(A), RoundUp), convert(T, 2), RoundUp)
+    rA = IntervalArithmetic._fround.(-, mA, inf.(A), RoundUp)
     return mA, rA
 end
 
