@@ -8,8 +8,10 @@
     @test (@exact 1.2 + 3.4im) isa Complex{<:ExactReal}
     @test_throws ArgumentError (@exact 1.2 + 3im)
 
-    @test ExactReal{Int}(3).value == 3
+    @test exact(3).value == 3
     @test_throws MethodError ExactReal{Float64}(1//3)
+    @test_throws MethodError ExactReal{Float64}(1.0)
+    @test_throws MethodError ExactReal(1.0)
 
     #
 
@@ -43,7 +45,7 @@
 
     #
 
-    @test isequal_interval(promote(bareinterval(1, 2), ExactReal(3))[2], bareinterval(3))
+    @test isequal_interval(promote(bareinterval(1, 2), exact(3))[2], bareinterval(3))
 
-    @test isequal_interval(promote(interval(1, 2), ExactReal(3))[2], interval(3))
+    @test isequal_interval(promote(interval(1, 2), exact(3))[2], interval(3))
 end
